import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DomainConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. Certificate source type that indicates whether the certificate is provided by the user or Okta. Accepted values: MANUAL, OKTA_MANAGED. Warning: Use of OKTA_MANAGED requires a feature flag to be enabled. Default value = MANUAL
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/domain#certificate_source_type Domain#certificate_source_type}
    */
    readonly certificateSourceType?: string;
    /**
    * Custom Domain name
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/domain#name Domain#name}
    */
    readonly name: string;
    /**
    * Indicates whether the domain should be verified during creation
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/domain#verify Domain#verify}
    */
    readonly verify?: boolean | cdktf.IResolvable;
}
export declare class DomainDnsRecords extends cdktf.ComplexComputedList {
    get expiration(): string;
    get fqdn(): string;
    get recordType(): string;
    get values(): string[];
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/okta/r/domain okta_domain}
*/
export declare class Domain extends cdktf.TerraformResource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/okta/r/domain okta_domain} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DomainConfig
    */
    constructor(scope: Construct, id: string, config: DomainConfig);
    private _certificateSourceType?;
    get certificateSourceType(): string;
    set certificateSourceType(value: string);
    resetCertificateSourceType(): void;
    get certificateSourceTypeInput(): string | undefined;
    dnsRecords(index: string): DomainDnsRecords;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get validationStatus(): string;
    private _verify?;
    get verify(): boolean | cdktf.IResolvable;
    set verify(value: boolean | cdktf.IResolvable);
    resetVerify(): void;
    get verifyInput(): boolean | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
